==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/authSession/MapRootAuthenticationSessionEntityFieldDelegate.java <==
package org.keycloak.models.map.authSession;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapRootAuthenticationSessionEntityFieldDelegate extends org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntity.AbstractRootAuthenticationSessionEntity implements org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntity> entityFieldDelegate;
    public MapRootAuthenticationSessionEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getExpiration() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.EXPIRATION);
    }
    @SuppressWarnings("unchecked") @Override public void setExpiration(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.EXPIRATION, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity> getAuthenticationSessions() {
        return (java.util.Set<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity>) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.AUTHENTICATION_SESSIONS);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthenticationSessions(java.util.Set<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.AUTHENTICATION_SESSIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Optional<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity> getAuthenticationSession(String p0) {
        return (java.util.Optional<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity>) entityFieldDelegate.mapGet(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.AUTHENTICATION_SESSIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addAuthenticationSession(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.AUTHENTICATION_SESSIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean removeAuthenticationSession(String p0) {
        return (Boolean) entityFieldDelegate.mapRemove(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.AUTHENTICATION_SESSIONS, p0);
    }
}

==> keycloak-model-map-22.0.0-sources.jar: org/keycloak/models/map/authSession/MapRootAuthenticationSessionEntityFieldDelegate.java <==
package org.keycloak.models.map.authSession;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapRootAuthenticationSessionEntityFieldDelegate extends org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntity.AbstractRootAuthenticationSessionEntity implements org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntity> entityFieldDelegate;
    public MapRootAuthenticationSessionEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void markUpdatedFlag() {
        entityFieldDelegate.markUpdatedFlag();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @Override public String toString() {
        return "%" + String.valueOf(entityFieldDelegate);
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getExpiration() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.EXPIRATION);
    }
    @SuppressWarnings("unchecked") @Override public void setExpiration(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.EXPIRATION, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getRealmId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.REALM_ID);
    }
    @SuppressWarnings("unchecked") @Override public void setRealmId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.REALM_ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Set<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity> getAuthenticationSessions() {
        return (java.util.Set<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity>) entityFieldDelegate.get(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.AUTHENTICATION_SESSIONS);
    }
    @SuppressWarnings("unchecked") @Override public void setAuthenticationSessions(java.util.Set<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.AUTHENTICATION_SESSIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Optional<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity> getAuthenticationSession(String p0) {
        return (java.util.Optional<org.keycloak.models.map.authSession.MapAuthenticationSessionEntity>) entityFieldDelegate.mapGet(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.AUTHENTICATION_SESSIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public void addAuthenticationSession(org.keycloak.models.map.authSession.MapAuthenticationSessionEntity p0) {
        entityFieldDelegate.collectionAdd(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.AUTHENTICATION_SESSIONS, p0);
    }
    @SuppressWarnings("unchecked") @Override public Boolean removeAuthenticationSession(String p0) {
        return (Boolean) entityFieldDelegate.mapRemove(org.keycloak.models.map.authSession.MapRootAuthenticationSessionEntityFields.AUTHENTICATION_SESSIONS, p0);
    }
}
